API documentation
=================

This page lists all modules in the epitasis library. If you find missing documentation,
feel free to open an issue or (better yet) submit a pull request!

.. toctree::
    :maxdepth: 2

    epistasis.models
    epistasis.pyplot
    epistasis.sampling
    epistasis.simulate
    epistasis.mapping
    epistasis.matrix
    epistasis.stats
